@@ -8,6 +8,9 @@
 pub static LANGUAGE: &str = "Rust";
 pub const THRESHOLD: i32 = 10;
 
+pub type Tuple0_0 = ();
+pub type Int8 = i8;
+
 pub struct Unit;
 
 pub fn array_length(array: &[u8]) -> usize {
